@@ -25,12 +25,13 @@ class EtsyAuth:
     __base_endpoint:str = "https://openapi.etsy.com/v3/application/"
     
     
-    def __post_init__(self):
+    @property
+    def get_user_info(self):
         user_info_endpoint = "oauth/userinfo"
         
         response = self.request(user_info_endpoint)
         
-        setattr(self, "user_info", OtherUser(**response))
+        return OtherUser(**response)
         
         
     def request(self, endpoint: str, method="GET", *args, **kwargs) -> dict:
